@@ -40,6 +40,7 @@ typedef struct _EGwItemClass   EGwItemClass;
 typedef struct _EGwItemPrivate EGwItemPrivate;
 
 typedef enum {
+	E_GW_ITEM_TYPE_MAIL,
 	E_GW_ITEM_TYPE_APPOINTMENT,
 	E_GW_ITEM_TYPE_TASK,
 	E_GW_ITEM_TYPE_CONTACT,
@@ -47,6 +48,7 @@ typedef enum {
 	E_GW_ITEM_TYPE_ORGANISATION,
 	E_GW_ITEM_TYPE_RESOURCE,
 	E_GW_ITEM_TYPE_CATEGORY,
+	E_GW_ITEM_TYPE_NOTIFICATION, 
 	E_GW_ITEM_TYPE_UNKNOWN
 	
 } EGwItemType;
@@ -59,6 +61,19 @@ typedef enum {
 
 } EGwItemChangeType;
 
+typedef enum {
+	E_GW_ITEM_STAT_ACCEPTED = 1<<0,
+	E_GW_ITEM_STAT_COMPLETED = 1<<1,
+	E_GW_ITEM_STAT_DELEGATED = 1<<2,
+	E_GW_ITEM_STAT_DELETED   = 1<<3,
+	E_GW_ITEM_STAT_FORWARDED = 1<<4,
+	E_GW_ITEM_STAT_OPENED    = 1<<5,
+	E_GW_ITEM_STAT_READ      = 1<<6,
+	E_GW_ITEM_STAT_REPLIED   = 1<<7,
+	E_GW_ITEM_STAT_DECLINED  = 1<<8,
+	E_GW_ITEM_STAT_NONE      = 1<<31
+} EGwItemStatus;
+
 struct _EGwItem {
 	GObject parent;
 	EGwItemPrivate *priv;
@@ -103,6 +118,27 @@ typedef struct {
 	char *display_name;
 } EGwItemOrganizer;
 
+typedef struct {
+	char *id ;
+	char *name ;
+	char *contentType ;
+	int size ;
+	char *date ;
+	char *data ;
+} EGwItemAttachment ;
+
+typedef enum {
+	E_GW_ITEM_NOTIFY_NONE,
+	E_GW_ITEM_NOTIFY_MAIL
+} EGwItemReturnNotify;
+
+typedef enum {
+	E_GW_ITEM_NONE,
+	E_GW_ITEM_DELIVERED,
+	E_GW_ITEM_DELIVERED_OPENED,
+	E_GW_ITEM_ALL
+} EGwItemTrack;
+
 GType       e_gw_item_get_type (void);
 EGwItem    *e_gw_item_new_empty (void);
 EGwItem    *e_gw_item_new_from_soap_parameter (const char *email, const char *container, SoupSoapParameter *param);
@@ -149,11 +185,38 @@ GList*      e_gw_item_get_im_list (EGwItem *item);
 void        e_gw_item_set_im_list (EGwItem *item, GList *im_list);
 void        e_gw_item_set_categories (EGwItem *item, GList *category_list);
 GList*      e_gw_item_get_categories (EGwItem *item);
+void 	    e_gw_item_set_to (EGwItem *item, const char *to) ;
+const char* e_gw_item_get_to (EGwItem *item) ;
+const char *e_gw_item_get_msg_content_type (EGwItem *item) ;
+guint32     e_gw_item_get_item_status (EGwItem *item);
 void e_gw_item_set_change (EGwItem *item, EGwItemChangeType change_type, char *field_name, gpointer field_value);
 gboolean e_gw_item_append_changes_to_soap_message (EGwItem *item, SoupSoapMessage *msg);
 void e_gw_item_set_category_name (EGwItem *item, char *cateogry_name);
 char* e_gw_item_get_category_name (EGwItem *item);
-void e_gw_item_set_source (EGwItem *item, char *source);
+void e_gw_item_set_sendoptions (EGwItem *item, gboolean set);
+void e_gw_item_set_reply_request (EGwItem *item, gboolean set);
+gboolean e_gw_item_get_reply_request (EGwItem *item);
+void e_gw_item_set_reply_within (EGwItem *item, char *reply_within);
+char *e_gw_item_get_reply_within (EGwItem *item);
+void e_gw_item_set_track_info (EGwItem *item, EGwItemTrack track_info);
+EGwItemTrack e_gw_item_get_track_info (EGwItem *item);
+void e_gw_item_set_autodelete (EGwItem *item, gboolean set);
+gboolean e_gw_item_get_autodelete (EGwItem *item);
+void e_gw_item_set_notify_completed (EGwItem *item, EGwItemReturnNotify notify);
+EGwItemReturnNotify e_gw_item_get_notify_completed (EGwItem *item);
+void e_gw_item_set_notify_accepted (EGwItem *item, EGwItemReturnNotify notify);
+EGwItemReturnNotify e_gw_item_get_notify_accepted (EGwItem *item);
+void e_gw_item_set_notify_declined (EGwItem *item, EGwItemReturnNotify notify);
+EGwItemReturnNotify e_gw_item_get_notify_declined (EGwItem *item);
+void e_gw_item_set_notify_opened (EGwItem *item, EGwItemReturnNotify notify);
+EGwItemReturnNotify e_gw_item_get_notify_opened (EGwItem *item);
+void e_gw_item_set_notify_deleted (EGwItem *item, EGwItemReturnNotify notify);
+EGwItemReturnNotify e_gw_item_get_notify_deleted (EGwItem *item);
+void e_gw_item_set_expires (EGwItem *item, char *expires);
+char *e_gw_item_get_expires (EGwItem *item);
+void e_gw_item_set_delay_until (EGwItem *item, char *delay_until);
+char *e_gw_item_get_delay_until (EGwItem *item);
+
 
 #define E_GW_ITEM_CLASSIFICATION_PUBLIC       "Public"
 #define E_GW_ITEM_CLASSIFICATION_PRIVATE      "Private"
@@ -175,6 +238,8 @@ void        e_gw_item_set_accept_level (EGwItem *item, const char *new_level);
 
 const char *e_gw_item_get_priority (EGwItem *item);
 void        e_gw_item_set_priority (EGwItem *item, const char *new_priority);
+const char *e_gw_item_get_task_priority (EGwItem *item);
+void        e_gw_item_set_task_priority (EGwItem *item, const char *new_priority);
 
 GSList *e_gw_item_get_recipient_list (EGwItem *item);
 void e_gw_item_set_recipient_list (EGwItem *item, GSList *new_recipient_list);
@@ -182,19 +247,18 @@ void e_gw_item_set_recipient_list (EGwItem *item, GSList *new_recipient_list);
 EGwItemOrganizer *e_gw_item_get_organizer (EGwItem *item);
 void e_gw_item_set_organizer (EGwItem  *item, EGwItemOrganizer *organizer);
 
+GSList * e_gw_item_get_attach_id_list (EGwItem *item) ;
+void e_gw_item_set_attach_id_list (EGwItem *item, GSList *attach_list) ;
+
 
 GSList *e_gw_item_get_recurrence_dates (EGwItem *item);
 void e_gw_item_set_recurrence_dates (EGwItem  *item, GSList *new_recurrence_dates);
 
+void e_gw_item_set_source (EGwItem *item, char *source) ;
 
 int e_gw_item_get_trigger (EGwItem *item);
 void e_gw_item_set_trigger (EGwItem *item, int trigger);
 
-typedef enum {
-	E_GW_ITEM_STAT_ACCEPTED,
-	E_GW_ITEM_STAT_DECLINED,
-	E_GW_ITEM_STAT_NONE
-} ItemStatus; 
 
 typedef struct {
 	char *email;
@@ -206,7 +270,7 @@ typedef struct {
 		E_GW_ITEM_RECIPIENT_NONE
 	} type;
 
-	ItemStatus status;
+	EGwItemStatus status;
 } EGwItemRecipient;
 
 gboolean    e_gw_item_append_to_soap_message (EGwItem *item, SoupSoapMessage *msg);
